;+
; NAME:
;	do_scanamorphos_otf_map
;
; PURPOSE:
;
;	Combine a list of reduced data from different observations for a single
;	object on a map. Uncorrelated 1/f noise can be removed as an option.
;
; CALLING SEQUENCE:
;
;	COMBINE_OTF_MAP, Scan_list, Mapradecstr
;
; INPUTS:
;
;	Scan_list:	List of observations.
;
; OPTIONAL INPUTS:
;
;	Project_list:	List of projects.
;			
; KEYWORD PARAMETERS:
;
;	DO_RCP:		Use optical distorsion file.
;		
;	REMOVEDRIFT:	Subtract 1/f uncorrelated noise.
;		
; OUTPUTS:
;
;	Mapradecstr:	Output map structure.
;	
; COMMON BLOCKS:
;
;	OBS1_CONFIGB:	Contains working directory, project name and calibration
;			table.
;	
; EXAMPLE:
;	
;		COMBINE_OTF_MAP, [49007,49008], Gum31_5_comb_str
;
;		COMBINE_OTF_MAP, [47536,48822,48825,49000,49281,47527], Ngc3576_comb_mask_str
;
;		COMBINE_OTF_MAP, [48814], Ngc2264c_48814_rdrift, /REMOVEDRIFT, /DO_RCP
;
;		COMBINE_OTF_MAP, [48814,48971], Ngc2264c_48814_48971_rdrift, /REMOVEDRIFT, /DO_RCP
;
; MODIFICATION HISTORY:
; 	
;-



pro do_scanamorphos_otf_map, scan_list, do_rcp=do_crp, project_list=project_list



if n_params() eq 0 then begin
	print, 'Calling sequence : '
	print, '	COMBINE_OTF_MAP, scan_list, mapradecstr, removedrift=removedrift, do_rcp=do_crp, project_list=project_list'
	return
endif


COMMON obs1_configb, work_dir, project_name, calibration_table  

init_obs, scan_number=scan_list[0], type='map', init_obs_str

; Usage:
; combine_otf_map, [49007,49008], gum31_5_comb_str

print, 'scan list : ', scan_list

numb_scan = n_elements(scan_list)

;;;;
;;;; 1/f uncorrelated noise removal (H. Roussel)
;;;;

;if not keyword_set(removedrift) then removedrift='0' else  removedrift='1'
;
;if removedrift eq '1' then begin

dir_in=init_obs_str.apexdata+'map_otf_xdr/'+init_obs_str.project_name+'/'

dir_rcp=init_obs_str.work_dir+'Calib_partemis'+'/'


if init_obs_str.pfov EQ '' then init_obs_str.pfov = 6.2


;remove_uncordrifts, visu=1, dir_in=dir_in, num_scans=scan_list, nsubscans=150, pfov=init_obs_str.pfov, $
;                         dir_rcp=dir_rcp


;echant = 3    ; facteur de rebin pour la construction du scan			
echant = 5    ; facteur de rebin pour la construction du scan	
	
for iscan = 0, numb_scan-1 do begin
  scan_number = scan_list(iscan)
  
init_obs, scan_number=scan_number, type='map', init_obs_strr
  
obsname = 'APEX-' + strtrim(string(scan_number),1)				;  Nov 2007

dirdef = init_obs_str.apexdata + 'basic_xdr/'



project_name=init_obs_str.project_name

if keyword_set(project_list) EQ 1 then begin

project=project_list[0]

   if n_elements(project_list) GT 1 then begin
   project=project_list[iscan]
   endif

endif else begin

project=project_name

endelse


subscan_liste = init_obs_strr.subscan_liste

subscan_name = project_name +'/' + strtrim(string(scan_number), 2) + '_' + subscan_liste

  for i=0, n_elements(subscan_liste)-1 do begin
      
  filename= init_obs_str.apexdata+'map_otf_xdr/'+project+'/otf_subscan_'+strtrim(string(scan_number),1)+'_'+subscan_liste(i)+'.xdr'
  filename2=init_obs_str.apexdata+'map_otf_xdr/'+project+'_do_map/otf_subscan_'+strtrim(string(scan_number),1)+'_'+subscan_liste(i)+'.xdr' ; contient donnees_red, produit
;                                                                                                                                             ; par remove_uncordrifts
  
  restore, filename=filename
  donnees_red_init = donnees_red
;;;;  restore, filename=filename2


if keyword_set(do_rcp) then begin
	
do_map_scan, donnees_red, positions, out_ima_dim, echant=echant, dx_rcp=init_obs_strr.dx_rcp, dy_rcp=init_obs_strr.dy_rcp, $
/do_rcp, carte_scan

endif else begin

do_map_scan, donnees_red, positions, out_ima_dim, echant=echant, carte_scan

endelse
	

subscanname = subscan_name(i)

save, filename=filename2, subscanname, carte_scan, donnees_cal, donnees_red
print, '-----> ' + filename2
	

endfor

endfor

;endif

	       
return
end
