
;+
; NAME:
;	NOISE_FFT_SKYDIP
;
; PURPOSE:
;
;	Calculate the optical opacity tau from a skydip observation		
;
; CALLING SEQUENCE:
;	
;	NOISE_FFT_SKYDIP, SKYDIP_NUMBER, NOISE_STR, band=band
;
; INPUTS:
;
;	SKYDIP_NUMBER:	Observation number.
;			
; OUTPUTS:
;
;	NOISE_STR:	Output noise structure.
;	
; EXAMPLE:	
;
;		NOISE_FFT_SKYDIP, 47519, sky_noise_str, band=450
;
; MODIFICATION HISTORY:
; 				
;			
;-

;PG2016
;pro noise_fft_skydip, skydip_number, noise_str, nopowermap=nopowermap, decorrel=decorrel
pro noise_fft_skydip, skydip_number, noise_str, nopowermap=nopowermap, decorrel=decorrel, band=band, tau_0=tau_0, tau_err=tau_err, tau_1=tau_1, off=off, sky=sky
;PG2016

if n_params() eq 0 then begin
	print, 'Calling sequence :'
	print, '	NOISE_FFT_SKYDIP, Skydip_number, Noise_str, band=band
	return
endif	



COMMON obs1_configb, work_dir, project_name

;PG2016
if not keyword_set(band) then spectral_band = 350 else spectral_band = band
;PG2016

;PG2016
;init_obs, scan_number=skydip_number, type='map', init_obs_str
init_obs, scan_number=skydip_number, type='map', init_obs_str, band=spectral_band
;PG2016

goodpix_ima=init_obs_str.goodpix_ima

window, 20
window, 21

;bidon = fltarr(35,39)
;bidon(24:28,31:36) = 1.
bidon = fltarr(73,39)
bidon(46:50,24:29) = 1.
mask = bidon

	
for i=0, n_elements(init_obs_str.subscan_liste)-1 do begin

 if keyword_set(nopowermap) then begin         ; do not calibrate data from V to pW

;PG2016
;  donnees = read_apex(init_obs_str.scan_number, init_obs_str.subscan_liste(i), filetype, $
;  calibration_camera=init_obs_str.calibration_camera, goodpix_ima=init_obs_str.goodpix_ima, /nopowermap)
  donnees = read_apex(init_obs_str.scan_number, band=spectral_band, init_obs_str.subscan_liste(i), filetype, $
  calibration_camera=init_obs_str.calibration_camera, goodpix_ima=init_obs_str.goodpix_ima, /nopowermap)
;PG2016

 endif else begin	                          ; calibrate data from V to pW or restore existing calibrated data

;PG2016
;  donnees = read_apex(init_obs_str.scan_number, init_obs_str.subscan_liste(i), filetype, $
;  calibration_camera=init_obs_str.calibration_camera, goodpix_ima=init_obs_str.goodpix_ima)
  donnees = read_apex(init_obs_str.scan_number, band=spectral_band, init_obs_str.subscan_liste(i), filetype, $
  calibration_camera=init_obs_str.calibration_camera, goodpix_ima=init_obs_str.goodpix_ima)
;PG2016

 endelse

  print, "Subscan : ", init_obs_str.subscan_name(i)
  print, "Elevation (deg) : ", donnees.elevatio
    
;  n_images = fix(15*donnees.freq)		; skydips
  n_images = fix(13.5*donnees.freq)		; skydips
;  n_images = 575
;  n_images = fix(10*donnees.freq)		; calibrations

  command = donnees.obslog.command                                ;  recuperation de donnees additionnelles dans les OBSLOG
	if strpos(command,'time=') ne -1L then begin			; 'angle=' is contained in command
	  command = strmid(command,strpos(command,'time='))
	endif else begin
	  command = -1
	endelse  
	if ((size(command))(1) eq 7) then begin				;  command is a string (i.e. strmid did not return -1)
	 	time = (strsplit(command,',',/extract))(0)
		time =  float(strmid(time,strpos(time,'=')+1))	; integration time (sec) of calibration subscans
		n_images = fix(time*donnees.freq)-5
	endif

  cube = donnees.cube(*,*,0:n_images-1)	

if keyword_set(decorrel) then begin
    test_decorrel, cube, mask, cube_corr, correl_matrice, a_matrice
endif else begin
    cube_corr = cube
endelse
;
  taille = size(cube)
  ndim = taille(3)
  lst = donnees.lst
  lst0 = lst(0:ndim-2)
  lst1 = lst(1:ndim-1)

  dt = dlst2dtloc(median(lst1-lst0))
  print, "Sampling time (sec) :", dt 
  
  time = findgen(ndim)*dt		; timeline in sec
  sfint = 1./(ndim*dt)		; smallest non-zero positive frequency in Hz
  frequency = findgen(1+ndim/2)*sfint
  freqmax = 1./(2.*dt)		; Nyquist frequency (highest frequency that
;					; can be sampled)
  donnees_corr = donnees
;  
if keyword_set(decorrel) then begin  
  donnees_corr.cube = cube_corr
endif
;
;  noise_fft_pro, donnees, init_obs_str.goodpix_ima, mean_level, mean_level_av, rms_noise, rms_noise_av, cube_pow_spec, pow_spec_av, ndim=ndim
  noise_fft_pro, donnees, init_obs_str.goodpix_ima, mean_level, mean_level_av, rms_noise, rms_noise_av, cube_pow_spec, pow_spec_av, ndim=ndim, /sub_mean
  print, "Mean level over valid pixels : ", mean_level_av
  print, "Mean rms noise over valid pixels : ", rms_noise_av
  
  cube_pow_spec = cube_pow_spec(*,*,0:n_images-1)
  pow_spec_av = pow_spec_av(0:n_images-1)
  
;  invntt_vector = fft(1./pow_spec_av,-1)
;  
;  window, 22
;  wset, 22
;  plot, time(0:ndim/2), invntt_vector(0:ndim/2)
; 
;  stop
  
  wset, 20
  pow_max = max(pow_spec_av(0:ndim/2))
  plot, frequency, pow_spec_av(0:ndim/2), xtitle="Frequency (Hz)", $
  ytitle="Relative amplitude", title="Mean power spectrum over valid pixels for scan "+init_obs_str.subscan_name(i)+ " @ "+ strtrim(spectral_band, 2)+ " microns", $
  xrange=[0,freqmax], yrange=[-0.1*pow_max/sqrt(2.),pow_max/2.], /XSTYLE  
;  xrange=[0,freqmax/1.7], yrange=[-0.1*pow_max/sqrt(2.),pow_max/2.], /XSTYLE

  noise_fft_pro, donnees_corr, init_obs_str.goodpix_ima, mean_level_corr, mean_level_corr_av, rms_noise_corr, rms_noise_corr_av, cube_corr_pow_spec, pow_spec_corr_av, ndim=ndim, /sub_mean
if keyword_set(decorrel) then begin
  print, "Mean level over valid pixels after decorrelation : ", mean_level_corr_av
  print, "Mean rms noise over valid pixels after decorrelation : ", rms_noise_corr_av
  print, "Improvement factor due to decorrelation (rms_noise_av/rms_noise_corr_av): ", rms_noise_av/rms_noise_corr_av  
endif
;
  cube_corr_pow_spec = cube_corr_pow_spec(*,*,0:n_images-1)
  pow_spec_corr_av = pow_spec_corr_av(0:n_images-1)
;
;stop

;PG2016  
;  champ  = [{scanname : init_obs_str.subscan_name(i), cube : cube, cube_corr : cube_corr, mean_level : mean_level, mean_level_av : mean_level_av, $
  champ  = [{scanname : init_obs_str.subscan_name(i), band : spectral_band, cube : cube, cube_corr : cube_corr, mean_level : mean_level, mean_level_av : mean_level_av, $
			rms_noise : rms_noise, rms_noise_av : rms_noise_av, elevatio : donnees.elevatio,  $
                        cube_pow_spec : cube_pow_spec , pow_spec_av : pow_spec_av, rms_noise_corr : rms_noise_corr, $
			rms_noise_corr_av : rms_noise_corr_av , cube_corr_pow_spec : cube_corr_pow_spec, $
			pow_spec_corr_av : pow_spec_corr_av }]
;PG2016
  
  IF i eq 0 THEN BEGIN

  	noise_str = [champ]

  ENDIF ELSE BEGIN	; i > 0
  
  	noise_str = [noise_str, champ]

  ENDELSE

endfor

;pro noise_fft_skydip, skydip_number, goodpix_ima, noise_str, dir_dat=dir_dat
;
; noise_fft_skydip, 47513, goodpix_ima, sky_47513_noise_str
; for i = 0, 4 do print, "Power = ", sky_47513_noise_str(i).mean_level_av,"  ", sky_47513_noise_str(i).scanname, "   El = ", sky_47513_noise_str(i).elevatio

amass = 1./sin(noise_str.elevatio*!pi/180.)
int   = noise_str.mean_level_av

loadct, 15
wset, 21
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [14.5,16.5]
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [15.5,17.5]
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [22.,25.]
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [21.,24.]
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [20.,23.]
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [19.5,23.]
;plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [19.5,24.]
plot, amass, int, psym = 2, /ynozero, xrange= [0.95,3.05], yrange = [min(int),max(int)]

chi = 0.
;apar = [0.5, 14.6, 3.3]
;apar = [0.65, 14.5, 3.0]
;apar = [1.5, 16.5, 6.8]
;apar = [0.82, 18.25, 5.0]
;apar = [0.93, 16.87, 6.46]
;apar = [0.9, 0.1, 0.16]
;apar = [0.5, 0.1, 0.16]
apar = [2.0, -0.15, 0.3]

;apar = [2.0, -0.08, 0.23]
if spectral_band eq 350. then apar(0) = 0.35 + 1.3*donnees.obslog.pwv    	    ;    At 350 mu  	2.*donnees.obslog.pwv     	    ;    At 350 mu
if spectral_band eq 450. then apar(0) = 0.28 + 1.045*donnees.obslog.pwv     	    ;    At 450 mu

;;apar = [1.3, -0.0, 0.16]
;;apar = [1.61, -0.01, 0.17]
;;apar = [1.05, 0.01, 0.18]
;;apar = [1.45, -0.02, 0.21]
;apar = [1.45, -0.05, 0.20]
;apar = [1.45, -0.02, 0.18] 	; 350 mu
apar = [1.00, -0.07, 0.21] 	; 350 mu
;apar = [1.00, -0.0116, 0.036] 	; 350 mu
apar = [1.25, 0.0, 0.20] 	; 450 mu

;print, " Initial apar  = ", apar

rms = apar*0.
;
;.run skydip_fun
skydip_fit = LMFIT(amass,int,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double)
;print, " apar = ", apar
skydip_fit = LMFIT(amass,int,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double)
;print, " apar = ", apar
;
skydip_fit = LMFIT(amass,int,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double); ,itmax=100,tol=1d-24)
;print, " apar = ", apar
skydip_fit = LMFIT(amass,int,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double); ,itmax=100,tol=1d-24)
;print, " apar = ", apar
;
;
skydip_fit = LMFIT(amass,int,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double); ,itmax=100,tol=1d-24)
;print, " apar = ", apar
skydip_fit = LMFIT(amass,int,APAR,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double); ,itmax=100,tol=1d-24)
;print, " apar = ", apar

;
oplot, amass, skydip_fit, psym=-1, color=130
;
;print, " Tau (350 microns) at zenith = ", apar(0), " +- ", rms(0)
print, " Tau ("+strtrim(spectral_band,2)+" microns) at zenith = ", apar(0), " +- ", rms(0)
print, " PWV (mm) = ", donnees.obslog.pwv
;
print, apar

tau_0 = apar(0)
tau_err = rms(0)

off = apar(1)
sky = apar(2)

;stop
;
wset, 20
;amass_ext = [0.,0.5,[amass]]
amass_ext = [findgen(6)*0.2,[amass]]
Result = skydip_fun(amass_ext,apar)
int_fit_ext = result(*,0)

;PG2016
;plot, amass_ext, int_fit_ext, psym = 0, /ynozero, xrange= [-0.05,3.05], yrange = [min(int_fit_ext),max(int_fit_ext)], xtitle="Airmass", $
;ytitle="Mean Power per pixel (pW) ", title="Skydip "+init_obs_str.subscan_name(0)+"  PWV (mm) = "+strcompress(string(donnees.obslog.pwv)), /XSTYLE, /YSTYLE
plot, amass_ext, int_fit_ext, psym = 0, /ynozero, xrange= [-0.05,3.05], yrange = [min(int_fit_ext),max(int_fit_ext)], xtitle="Airmass", $
ytitle="Mean Power per pixel (pW) ", $
title="Skydip "+init_obs_str.subscan_name(0)+"  PWV (mm) = "+strcompress(string(donnees.obslog.pwv)) + " @ "+ strtrim(spectral_band, 2)+ " microns", $
/XSTYLE, /YSTYLE
;PG2016

oplot, amass, int, psym = 2

print, "Offset power at Airmass = 0 : ", int_fit_ext(0), " pW"
print, "Power contribution from atmosphere at zenith (Airmass = 1) : ", int_fit_ext(5)-int_fit_ext(0), " pW"
print, "Relative contribution of atmosphere at zenith (Airmass = 1) : ", (int_fit_ext(5)-int_fit_ext(0))/int_fit_ext(0)

;stop

;
;			PRINTING POWER SPECTRUM
;
set_plot,'ps'
device,file="skydip_"+init_obs_str.obsname+".ps"

;PG2016
;plot, amass_ext, int_fit_ext, psym = 0, /ynozero, xrange= [-0.05,3.05], yrange = [min(int_fit_ext),max(int_fit_ext)], xtitle="Airmass", $
;ytitle="Mean Power per pixel (pW) ", title="Skydip "+init_obs_str.subscan_name(0)+"  PWV (mm) = "+strcompress(string(donnees.obslog.pwv)), /XSTYLE, /YSTYLE
plot, amass_ext, int_fit_ext, psym = 0, /ynozero, xrange= [-0.05,3.05], yrange = [min(int_fit_ext),max(int_fit_ext)], xtitle="Airmass", $
ytitle="Mean Power per pixel (pW) ", $
title="Skydip "+init_obs_str.subscan_name(0)+"  PWV (mm) = "+strcompress(string(donnees.obslog.pwv))+ " @ "+ strtrim(spectral_band, 2)+ " microns", $
/XSTYLE, /YSTYLE
;PG2016

oplot, amass, int, psym = 2

device,/close
set_plot,'x'

;openW, lun, init_obs_str.Tau_table_, /APPEND, /GET_LUN

;tau=apar[0]
;tau=STRTRIM(apar[0], 2)

;date=donnees.date_obs
;date=clean_chaine(date,':','-')
;date=clean_chaine(date,':','-')
;date=clean_chaine(date,'T','-')
;date=strsplit(date,/extract,'-')
;date=long(date)

;datemjd=(julday(date(1),date(2),date(0),date(3),date(4),date(5))-2400000.5)

;printf, lun, skydip_number, double(datemjd), [tau, donnees.date_obs]

;close, lun


;
;apar = [1.5, 16.5, 6.8]
;apar = [0.82, 18.25, 5.0]
fitapar = [1, 0, 0]		; fitting only tau
; 
skydip_fit = LMFIT(amass,int,APAR,fita=fitapar,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double)

;
;oplot, amass, skydip_fit, psym=-1, color=130
;
;PG2016
;print, " Tau (350 microns) at zenith = ", apar(0), " +- ", rms(0), "... when fitting only Tau and fixing other 2 parameters"
print, " Tau ("+strtrim(spectral_band,2)+" microns) at zenith = ", apar(0), " +- ", rms(0), "... when fitting only Tau and fixing other 2 parameters"
;PG2016
;
tau_1 = apar(0)
;
;apar = [1.7, 16.5, 6.8]
;fitapar = [0., 1, 1]		; fitting all parameters but tau
; 
;skydip_fit = LMFIT(amass,int,APAR,fita=fitapar,SIGMA=RMS,CHISQ=chi,FUNCTION_NAME='skydip_fun',/double)
;
;oplot, amass, skydip_fit, psym=-1, color=130
;
;
;print, "    "
;print, "Best parameters when tau is fixed :"
;print, apar
;free_lun, lun
;
;stop

return
end
