;+
; NAME:
;	READ_APEXOBSLOG
;
; PURPOSE:
;
;	Read additional informations stored in a HTML file about an observation.
;
; CALLING SEQUENCE:
;	
;	Obslog = READ_APEXOBSLOG(Scannumber)
;
; INPUTS:
;
;	Scannumber:	Observation ID number.
;		
;
; KEYWORD PARAMETERS:
;
;	ALL:	Read all the obslogs.
;		
;
; COMMON BLOCKS:
;
;	OBS1_CONFIGB:	Contains working directory, project and calibration table name.
;			
;
; EXAMPLE:
;
;		Obslog = READ_APEXOBSLOG(47527,/ALL)
;
; MODIFICATION HISTORY:
; 	
;-

function read_pointings_apexobslog

COMMON obs1_configb

if n_params() eq 0 then begin
	print, 'Calling sequence :'
	print, '	pointing_struc = READ_POINTINGS_APEXOBSLOG()
	return, -1
endif	

apexdata=work_dir+'apexdata/'

restore, apexdata+'obslogs/apex_obslog.xdr', /verb

id_point = where(apexlog_struct.geom eq 'SINGLE-SPIRAL' and apexlog_struct.type eq 'POINT', count)
	
if count gt 0 then begin
    outlog = apexlog_struct(id_point)
endif

id_skydip = where(apexlog_struct.type eq 'SKYDIP' and apexlog_struct.projectid eq 'E-091.C-0870A-2013' and strmid(apexlog_struct.date,0,4) eq '2014' , sky_count)

for i = 0, n_elements(id_skydip)-1 do begin $
& print, "Skydip_number: ", apexlog_struct(id_skydip(i)).number, "   Observing date: ", apexlog_struct(id_skydip(i)).date, "   PWV (mm): ", apexlog_struct(id_skydip(i)).pwv & $
endfor


return, outlog

end
