;+
; NAME:
;	ROT_DXDY2DAZDEL
;
; PURPOSE:
;
;	Converts set of coordinates in detector coordinates to azimuth and elevation.
;	
; CALLING SEQUENCE:
;
;	ROT_DXDY2DAZDEL, Delta_x, Delta_y, Rot_angle, Delta_az, Delta_el
;
; INPUTS:
;
;;;;;;	Elev:		Elevation   (was used with P-ArTMiS at Nasmyth focus)
;   	Rot_angle   	ArTMiS rotation angle (degrees)    	    	    	PhA2016
;	Delta_x:	Offset in detector coordinates along x.
;	Delta_y:	Offset in detector coordinates along y.		
;
; OUTPUTS:
;
;	Delta_az:	Offet in azimuth.
;	Delta_el:	Offet in elevation.
;
; EXAMPLE:
;
;;;;;;;;		ROT_DXDY2DAZDEL, Delta_x, Delta_y, Elev, Delta_az, Delta_el
;   	    	    	ROT_DXDY2DAZDEL, Delta_x, Delta_y, Rot_angle, Delta_az, Delta_el
;
; MODIFICATION HISTORY:
; PhA2016  modified from P-ArTMiS to ArTMiS configuration
; 	
;-

;;PRO ROT_dxdy2dazdel, delta_x, delta_y, elev, delta_az, delta_el
PRO ROT_dxdy2dazdel, delta_x, delta_y, rot_angle, delta_az, delta_el

; convert set of coordinates in detector coordinates to azimuth and elevation      NB:  Strictly speaking, not a rotation for Artemis350 (Cassegrain)

;rot_angle = elev*!pi/180								; P-Artemis (Nasmyth)
;delta_az = cos(rot_angle)*delta_x - sin(rot_angle)*delta_y
;delta_el = sin(rot_angle)*delta_x + cos(rot_angle)*delta_y

;;rot_angle = (-10.0)*!pi/180.
;rot_angle = (-12.0)*!pi/180.

rot_angle = rot_angle*!pi/180.	    	    	    	    	    	    	    	; Conversion from deg to radians        PhA2016

delta_az = cos(rot_angle)*(-delta_x) - sin(rot_angle)*delta_y				;  Artemis350 (Cassegrain) July 2013
delta_el = sin(rot_angle)*(-delta_x) + cos(rot_angle)*delta_y

;delta_az = delta_x									; Artemis (Cassegrain)
;delta_el = delta_y

return 
end
