pro unzip_artemis, archive_dir=archive_dir
;
; Usage (examples): unzip_artemis
;   	    	    unzip_artemis, archive_dir="/Users/pandre/kosma/artemis/apexdata/archive/" 
;

COMMON obs1_configb

if n_params() lt 0 then begin
	print, 'Calling sequence : '
	print, '         UNZIP_ARTEMIS, archive_dir=archive_dir'
	print, '               archive_dir : folder containing archive files, terminated by /'
	print, '               archive fits files must be in archive folder'
;	return
endif

if not keyword_set(archive_dir) then begin

 ;file = findfile(work_dir + 'apexdata/rawdata/*APEXBOL.2016*.fits', count=count)
 files = findfile(work_dir + 'apexdata/archive/*APEXBOL.2016*.fits', count=n_files)

 archive_dir = work_dir + 'apexdata/archive/'

endif else begin

 files = findfile(archive_dir + '*APEXBOL.2016*.fits', count=n_files)

endelse


if n_files eq 0 then begin
	print, 'UNZIP_ARTEMIS : No archive file found'
	return
endif

;if n_files ne 1 then begin
;	print, 'UNZIP_ARTEMIS : Too many files to unzip'
;	print, file
;	return
;endif

for k=0, n_files-1 do begin

 file = files(k)

 scan = mrdfits(file, 1, header)
 scan_num_str = strtrim(string(fxpar(header, 'SCANNUM')),1)
 
 date_str = strmid(fxpar(header, 'DATE-OBS'),0,10)
 
 projid_str = fxpar(header, 'PROJID')
 

 ; 2013-09-04T15-01-59.120-84508-APEX-57276-2013-09-02-O-091.F-9300A-2013.fits

 ;;pos0 = strpos(file, '-APEX-')
 ;pos0 = strpos(file, 'APEXBOL')
 ;pos1 = strpos(file, '.fits')

 ;Obs = strmid(file, pos0+1, pos1 - pos0-1)

; obs = scan_num_str

 obs = 'APEX-' + scan_num_str + '-' + date_str + '-' + projid_str
; print, " obs = ", obs

; bidon = findfile(work_dir + 'apexdata/rawdata/APEX-' + obs + '*', count=count)

 bidon = findfile(work_dir + 'apexdata/rawdata/' + obs, count=count)

 if count ne 0 then begin
	print, 'UNZIP_ARTEMIS : Destination folder already exists - UNZIP cancelled'
	print, ''
	return
 endif

 spawn, 'mkdir ' + work_dir + 'apexdata/rawdata/' + obs

; scan = mrdfits(file, 1, header)

 mwrfits, scan, work_dir + 'apexdata/rawdata/' + obs + '/' + 'SCAN.fits', header

 nsubs = fxpar(header, 'NSUBS')

 febepar = mrdfits(file, 2, header)
 mwrfits, febepar, work_dir + 'apexdata/rawdata/' + obs + '/' + 'ARTEMIS450-BEAR1-FEBEPAR.fits', header

 febepar = mrdfits(file, 3, header)
 mwrfits, febepar, work_dir + 'apexdata/rawdata/' + obs + '/' + 'ARTEMIS350-BEAR1-FEBEPAR.fits', header


 for i=0, nsubs-1 do begin
	subscandir = work_dir + 'apexdata/rawdata/' + obs + '/' + strtrim(i+1, 2)
	spawn, 'mkdir ' + subscandir
	
	datapar = mrdfits(file, 7*(i+1)-3, header)
	mwrfits, datapar, subscandir + '/' + 'ARTEMIS450-BEAR1-DATAPAR.fits', header
	
	datapar = mrdfits(file, 7*(i+1)-3+1, header)
	mwrfits, datapar, subscandir + '/' + 'ARTEMIS350-BEAR1-DATAPAR.fits', header

	arraydata = mrdfits(file, 7*(i+1)-3+2, header)
	mwrfits, arraydata, subscandir + '/' + 'ARTEMIS450-BEAR1-ARRAYDATA-2.fits', header
	
	arraydata = mrdfits(file, 7*(i+1)-3+3, header)
	mwrfits, arraydata, subscandir + '/' + 'ARTEMIS450-BEAR1-ARRAYDATA-1.fits', header
	
	arraydata = mrdfits(file, 7*(i+1)-3+4, header)
	mwrfits, arraydata, subscandir + '/' + 'ARTEMIS350-BEAR1-ARRAYDATA-2.fits', header
	
	arraydata = mrdfits(file, 7*(i+1)-3+5, header)
	mwrfits, arraydata, subscandir + '/' + 'ARTEMIS350-BEAR1-ARRAYDATA-1.fits', header
	
	monitor = mrdfits(file, 7*(i+1)-3+6, header)
	mwrfits, monitor, subscandir + '/' + 'MONITOR.fits', header
	
 endfor
 
endfor 

return
end
